require 'thor'

module LogicBomb
  class Cli < Thor
    include Thor::Actions

    def self.exit_on_failure?
      true
    end
 
    desc "config-gen", "Generate the YAML config file to fill out"
    def config_gen
      require 'logicbomb/generators/config_gen'
      LogicBomb::Generators::ConfigGen.start
    end

    desc "install CONFIG", "Installs this as a systemd Linux service to run the daemon with CONFIG at startup"
    def install(config)
      require 'logicbomb/generators/installer'
      LogicBomb::Generators::Installer.start([config])
    end

    desc "daemon CONFIG", "Run the daemon with CONFIG"
    def daemon(config)
      yaml = load_yaml config
      mailer = create_mailer yaml
      create_ping(yaml, mailer).daemon
    end

    desc "test-email CONFIG", "Send a test email to everyone in the CONFIG's mail-list"
    def test_email(config)
      yaml = load_yaml config
      puts "YAML loaded. Sending email..."
      create_mailer(yaml).test_email
      puts "Sent."
    end
    
    private
    def load_yaml(config)
      require 'yaml'
      YAML::load File.open(config)
    end

    def create_mailer(yaml)
      require 'logicbomb/mailer'
      Mailer.new(
        endpoint: yaml["mail-endpoint"],
        user: yaml["mail-username"],
        password: yaml["mail-password"],
        mail_send_to_list: yaml["mail-to-list"]
      )
    end

    def create_ping(yaml, mailer)
      require 'logicbomb/ping'
      Ping.new(
        ping: yaml["ping"],
        tracert: yaml["tracert"],
        interval: yaml["interval"],
        mailer: mailer
      )
    end
  end
end
