require 'thor'

module LogicBomb
  module Generators
    class Installer < Thor::Group
      include Thor::Actions

      argument :config, type: :string

      def self.source_root
        File.expand_path(File.join(File.dirname(__FILE__), '../templates'))
      end

      def install
        @config = File.expand_path config
        copy_template
        reload_daemon
        enable_logicbomb
        start_logicbomb
      end

      private
      def copy_template
        begin
          template("logicbomb.service", "/etc/systemd/system/logicbomb.service")
        rescue Errno::EACCES
          puts "To install the daemon you need sudo access since we hit systemd."
          puts "Try again with rvmsudo if you have it, otherwise sudo."
          exit 1
        end
      end

      def reload_daemon
        puts "Reloading the daemon..."
        run_command 'sudo systemctl daemon-reload'
      end

      def enable_logicbomb
        puts "Success. Enabling logicbomb service..."
        run_command('sudo systemctl enable logicbomb')

      end

      def start_logicbomb
        puts "Success. Starting logicbomb..."
        run_command('sudo systemctl start logicbomb')
      end

      def run_command(cmd)
        exit_bool = system(cmd)
        return if exit_bool
        puts "Error running `#{cmd}'. Quitting"
        exit 1
      end
    end
  end
end
