require 'viewpoint'
require 'date'

module LogicBomb
  class Mailer
    TEST_EMAIL_SUBJECT = "Test email for logicbomb"
    TEST_EMAIL_BODY = "You are receiving this email because you are subscribed to alerts when " \
                      "logicbomb detects an IP failing to ping. You will get an email when the " \
                      "pings fail."
    
    def initialize(endpoint:, user:, password:, mail_send_to_list:)
      @user, @password = user, password
      @endpoint, @to_list = endpoint, mail_send_to_list
    end

    def test_email
      send_email(
        subject: TEST_EMAIL_SUBJECT,
        body: TEST_EMAIL_BODY
      )
    end
    
    def mail(ping, tracert)
      send_email(
        subject: "Internet outage #{DateTime.now}",
        body: compose(ping, tracert)
      )
    end

    private
    def send_email(opts={})
      opts[:to_recipients] = @to_list unless opts.key?(:to_recipients)
      Viewpoint::EWSClient.new(@endpoint, @user, @password)
        .send_message(opts)
    end

    def compose(ping, tracert)
      "LogicBomb classified these pings as failures:\n#{ping}" \
      "And ran traceroutes to help diagnose:\n#{tracert}"
    end
  end
end
